from fastapi import APIRouter
from sw8logger import build_logger

router = APIRouter()

logger = build_logger(__name__)

@router.get("/")
def home():
    logger.info("Handling request")
    return {"status": "ok"}


import base64
from starlette.middleware.base import BaseHTTPMiddleware
from fastapi import Request
from starlette.responses import Response
from .context import trace_id_ctx
import logging

class RequestIdFilter(logging.Filter):
    def filter(self, record):
        record.trace_id = trace_id_ctx.get()
        return True

class LogRequestMiddleware(BaseHTTPMiddleware):
    async def dispatch(self, request: Request, call_next):
        # token = trace_id_ctx.set(trace_id)
        # print("dispatch....", trace_id)
        try:

            # 打印请求基础元数据
            # print("request.headers:", request.headers,"request url:", request.url)
            # 转换 headers 为普通字典
            headers = {k: v for k, v in request.headers.items()}
            _header_sw8 = headers.get("sw8")
            # print("test--sw8:", _header_sw8)
            trace_id = "null-given"
            if _header_sw8:
                sw8_split = _header_sw8.split("-")
                if len(sw8_split) >= 2:
                    try:
                        trace_id = base64.b64decode(sw8_split[1]).decode('utf-8')
                    except Exception:
                        trace_id = "invalid"


            trace_id_ctx.set(trace_id)
            response: Response = await call_next(request)

            return response

        except Exception as e:
            print(f"trace_id-{trace_id}--LogRequestMiddleware 执行异常: {str(e)}")
        finally:
            trace_id = "null-failed"
            trace_id_ctx.set(trace_id)
            # print("finally....")



from fastapi import FastAPI
from test_1 import router as test_router
from sw8logger import LogRequestMiddleware

app = FastAPI()
app.add_middleware(LogRequestMiddleware)

app.include_router(test_router)

if __name__ == "__main__":
    import uvicorn
    uvicorn.run(app, host="0.0.0.0", port=8000)


import logging
from typing import Optional
from .context import trace_id_ctx
from .middleware import RequestIdFilter, LogRequestMiddleware
__version__ = "0.1.0"

def build_logger(
    name: str,
    level: int = logging.INFO,
    log_file: Optional[str] = None
) -> logging.Logger:
    """
    构建带 trace_id 上下文的日志记录器。
    
    Args:
        name: Logger 名称（通常为 __name__）
        level: 日志级别，默认 INFO
        log_file: 可选，日志输出到文件路径；若为 None，则输出到控制台
    
    Returns:
        配置好的 logger 实例
    """
    logger = logging.getLogger(name)
    logger.setLevel(level)

    # 避免重复添加 handler
    if logger.handlers:
        return logger

    # 创建 handler
    if log_file:
        handler = logging.FileHandler(log_file)
    else:
        handler = logging.StreamHandler()

    # 设置格式（包含 trace_id）
    formatter = logging.Formatter(
        "[%(asctime)s] [%(trace_id)s] %(levelname)s - %(name)s - %(message)s"
    )
    handler.setFormatter(formatter)

    # 添加 filter 和 handler
    logger.addFilter(RequestIdFilter())
    logger.addHandler(handler)

    return logger
